@@ -84,7 +84,7 @@ def jssource_file(file_path, beautify=True, encoding="utf-8"):
         opts.wrap_line_length = 120
         opts.end_with_newline = True
         opts.preserve_newlines = True
-        opts.operator_position = "after_newline"
+        opts.operator_position = "after-newline"
         opts.eol = "\r\n"
         result = jsbeautifier.beautify(contents, opts=opts)
 
@@ -151,7 +151,9 @@ def jssource_walker(arguments, directory_name, names):
         # print a message a message about the jssource
         # operation that is going to be performed and
         # then runs the operation with the correct path
-        extra.echo("Transforming javascript source file (beautify): %s" % valid_complete_name)
+        extra.echo(
+            "Transforming JavaScript source file (beautify): %s" % valid_complete_name
+        )
         jssource_file(valid_complete_name)
 
 
